@@ -14,14 +14,18 @@
 #' da.longley<-dominanceAnalysis(lm(Employed~.,longley))
 #' averageContribution(da.longley)
 
-
-
 averageContribution<-function(da.object, fit.functions=NULL) {
   checkDominanceAnalysis(da.object)
   if(is.null(fit.functions)) {
     fit.functions=da.object$fit.functions
   }
   out<-da.object$contribution.average[fit.functions]
+  out<-lapply(out,function(xx) {
+    names(xx)<-replaceTermsInString(names(xx),da.object$terms)
+    xx
+  })
+
+  #print(out)
   class(out)<-c("daAverageContribution","list")
   out
 }
@@ -31,6 +35,5 @@ averageContribution<-function(da.object, fit.functions=NULL) {
 print.daAverageContribution<-function(x,...) {
   cat("\nAverage Contribution by predictor\n")
   print(round(t(sapply(x,I)),3))
-
   invisible(x)
 }
